@@ -6,27 +6,24 @@ OC.L10N.register(
     "New note" : "Nova nota",
     "Open in edit mode" : "Abrir no modo de edição",
     "Open in preview mode" : "Abrir no modo de visualização",
-    "No notes yet" : "Sem notas ainda",
     "All notes" : "Todas as notas",
     "Categories" : "Categorias",
-    "Loading …" : "A carregar...",
+    "No notes yet" : "Sem notas ainda",
+    "Remove from favorites" : "Remover de favoritos",
+    "Add to favorites" : "Adicionar aos favoritos",
+    "Share" : "Share",
+    "Rename" : "Rename",
+    "Delete note" : "Apagar nota",
+    "Use current version" : "Usar esta versão",
+    "Edit" : "Editar",
+    "Preview" : "Pré-visualização",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "This week" : "Esta semana",
     "Last week" : "Ultima semana",
     "This month" : "Este mês",
     "Last month" : "Ultimo mês",
-    "Rename" : "Renomear",
-    "Delete note" : "Apagar nota",
-    "Remove from favorites" : "Remover de favoritos",
-    "Add to favorites" : "Adicionar aos favoritos",
-    "Use current version" : "Usar esta versão",
-    "Details" : "Detalhes",
-    "Edit" : "Editar",
-    "Preview" : "Pré-visualização",
-    "Category" : "Categoria",
-    "_%n word_::_%n words_" : ["%n palavra","%n palavras","%n palavras"],
-    "Android app" : "Aplicação Android",
-    "iOS app" : "Aplicação iOS"
+    "Loading …" : "A carregar...",
+    "Tasks" : "Tarefas"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
